Module fixtures

Module fixtures 

Test fixture builders for creating domain objects.

These functions provide convenient constructors for test data, using sensible defaults while allowing customization.

Functions

allocation
Create an allocation for a job on a node.
batch_job_spec
Create a batch job spec.
constrained_job_spec
Create a job spec with constraints.
constraint
Create a constraint.
forge_job_spec
Create a job spec that looks like a forge-deployed workload.
job
Create a minimal job with sensible defaults.
job_spec
Create a job spec (pre-submission form).
job_spec_with_group
Create a job spec with specific group configuration.
job_with_group
Create a job with a specific task group configuration.
node_meta
Create a node metadata entry.
node_meta_with_os
Create a node metadata entry with custom attributes baked into os/arch.
pending_release
Create a pending release.
release
Create an active release.
task
Create an exec task with given resource requirements.