pub fn allocation(job_id: &str, group_name: &str, node_id: &str) -> AllocationExpand description
Create an allocation for a job on a node.
pub fn allocation(job_id: &str, group_name: &str, node_id: &str) -> AllocationCreate an allocation for a job on a node.