Test fixture builders for creating domain objects.
These functions provide convenient constructors for test data, using sensible defaults while allowing customization.
Functions
- allocation
- Create an allocation for a job on a node.
- batch_
job_ spec - Create a batch job spec.
- constrained_
job_ spec - Create a job spec with constraints.
- constraint
- Create a constraint.
- forge_
job_ spec - Create a job spec that looks like a forge-deployed workload.
- job
- Create a minimal job with sensible defaults.
- job_
spec - Create a job spec (pre-submission form).
- job_
spec_ with_ group - Create a job spec with specific group configuration.
- job_
with_ group - Create a job with a specific task group configuration.
- node_
meta - Create a node metadata entry.
- node_
meta_ with_ os - Create a node metadata entry with custom attributes baked into os/arch.
- pending_
release - Create a pending release.
- release
- Create an active release.
- task
- Create an exec task with given resource requirements.